==> react-atom-toast-1.7.0.tgz: package/lib/index.js <==
import { jsxs as _jsxs } from "react/jsx-runtime";
import { jsx as _jsx } from "react/jsx-runtime";
import { useState, useEffect, useRef, useCallback } from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import { AUTO_CLOSE_TIMES, BASE_CLASS, EFFECT_DELAY, POSITIONS } from './config';

function AtomToast(_ref) {
  var _cx;

  var _ref$autoClose = _ref.autoClose,
      autoClose = _ref$autoClose === void 0 ? true : _ref$autoClose,
      _ref$autoCloseTime = _ref.autoCloseTime,
      autoCloseTime = _ref$autoCloseTime === void 0 ? AUTO_CLOSE_TIMES.medium : _ref$autoCloseTime,
      children = _ref.children,
      _ref$effect = _ref.effect,
      effect = _ref$effect === void 0 ? true : _ref$effect,
      _ref$globalClose = _ref.globalClose,
      globalClose = _ref$globalClose === void 0 ? false : _ref$globalClose,
      _ref$iconClose = _ref.iconClose,
      iconClose = _ref$iconClose === void 0 ? null : _ref$iconClose,
      _ref$onClose = _ref.onClose,
      onClose = _ref$onClose === void 0 ? function () {} : _ref$onClose,
      _ref$position = _ref.position,
      position = _ref$position === void 0 ? POSITIONS.topRight : _ref$position,
      _ref$show = _ref.show,
      showFromProps = _ref$show === void 0 ? true : _ref$show;

  var _useState = useState(showFromProps),
      show = _useState[0],
      setShow = _useState[1];

  var _useState2 = useState(true),
      delay = _useState2[0],
      setDelay = _useState2[1];

  var autoCloseTimeout = useRef();
  var delayTimeout = useRef();
  var toastRef = useRef();
  var containerClassName = cx(BASE_CLASS + "-container", BASE_CLASS + "-position--" + position, (_cx = {}, _cx[BASE_CLASS + "-effect--" + position] = effect, _cx[BASE_CLASS + "-effect--hide"] = effect && delay, _cx));
  var handleClose = useCallback(function () {
    if (effect) setDelay(true);
    setShow(false);
    if (!effect) onClose();
  }, [effect, onClose]);
  useEffect(function () {
    setShow(showFromProps);
  }, [showFromProps]);
  useEffect(function () {
    if (autoClose) {
      autoCloseTimeout.current = setTimeout(function () {
        handleClose();
      }, autoCloseTime);
    }

    return function () {
      return clearTimeout(autoCloseTimeout.current);
    };
  }, [autoClose, autoCloseTime, handleClose]);
  useEffect(function () {
    // open effect
    if (effect && show && delay) {
      delayTimeout.current = setTimeout(function () {
        setDelay(false);
      }, EFFECT_DELAY.open);
    } // close effect


    if (effect && !show) {
      delayTimeout.current = setTimeout(function () {
        setDelay(false);
        onClose();
      }, EFFECT_DELAY.close);
    }

    return function () {
      return clearTimeout(delayTimeout.current);
    };
  }, [delay, effect, onClose, show]);
  useEffect(function () {
    if (globalClose) {
      var handleClickOutside = function handleClickOutside(e) {
        if (!toastRef.current.contains(e.target)) {
          handleClose();
        }
      };

      window.addEventListener('mousedown', handleClickOutside);
      return function () {
        window.removeEventListener('mousedown', handleClickOutside);
      };
    }
  }, [globalClose, handleClose]);
  if (!show && !delay) return null;
  return /*#__PURE__*/_jsx("div", {
    className: containerClassName,
    children: /*#__PURE__*/_jsxs("div", {
      className: BASE_CLASS,
      ref: toastRef,
      children: [/*#__PURE__*/_jsx("div", {
        onClick: handleClose,
        className: BASE_CLASS + "-icon",
        children: iconClose
      }), children]
    })
  });
}

AtomToast.displayName = 'AtomToast';
export { POSITIONS as atomToastPositions, AUTO_CLOSE_TIMES as atomToastAutoCloseTimes };
export default AtomToast;

==> react-atom-toast-1.8.0.tgz: package/lib/index.js <==
import { useState, useEffect, useRef, useCallback } from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import { AUTO_CLOSE_TIMES, BASE_CLASS, EFFECT_DELAY, POSITIONS } from './config.js';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";

function AtomToast(_ref) {
  var _cx;

  var _ref$autoClose = _ref.autoClose,
      autoClose = _ref$autoClose === void 0 ? true : _ref$autoClose,
      _ref$autoCloseTime = _ref.autoCloseTime,
      autoCloseTime = _ref$autoCloseTime === void 0 ? AUTO_CLOSE_TIMES.medium : _ref$autoCloseTime,
      children = _ref.children,
      _ref$effect = _ref.effect,
      effect = _ref$effect === void 0 ? true : _ref$effect,
      _ref$globalClose = _ref.globalClose,
      globalClose = _ref$globalClose === void 0 ? false : _ref$globalClose,
      _ref$iconClose = _ref.iconClose,
      iconClose = _ref$iconClose === void 0 ? null : _ref$iconClose,
      onClose = _ref.onClose,
      _ref$position = _ref.position,
      position = _ref$position === void 0 ? POSITIONS.topRight : _ref$position,
      _ref$show = _ref.show,
      showFromProps = _ref$show === void 0 ? true : _ref$show;

  var _useState = useState(showFromProps),
      show = _useState[0],
      setShow = _useState[1];

  var _useState2 = useState(true),
      delay = _useState2[0],
      setDelay = _useState2[1];

  var autoCloseTimeout = useRef();
  var delayTimeout = useRef();
  var toastRef = useRef();
  var containerClassName = cx(BASE_CLASS + "-container", BASE_CLASS + "-position--" + position, (_cx = {}, _cx[BASE_CLASS + "-effect--" + position] = effect, _cx[BASE_CLASS + "-effect--hide"] = effect && delay, _cx));
  var handleClose = useCallback(function () {
    if (effect) setDelay(true);
    setShow(false);
    if (!effect && typeof onClose === 'function') onClose();
  }, [effect, onClose]);
  useEffect(function () {
    setShow(showFromProps);
  }, [showFromProps]);
  useEffect(function () {
    if (autoClose) {
      autoCloseTimeout.current = setTimeout(function () {
        handleClose();
      }, autoCloseTime);
    }

    return function () {
      return clearTimeout(autoCloseTimeout.current);
    };
  }, [autoClose, autoCloseTime, handleClose]);
  useEffect(function () {
    // open effect
    if (effect && show && delay) {
      delayTimeout.current = setTimeout(function () {
        setDelay(false);
      }, EFFECT_DELAY.open);
    } // close effect


    if (effect && !show) {
      delayTimeout.current = setTimeout(function () {
        setDelay(false);
        typeof onClose === 'function' && onClose();
      }, EFFECT_DELAY.close);
    }

    return function () {
      return clearTimeout(delayTimeout.current);
    };
  }, [delay, effect, onClose, show]);
  useEffect(function () {
    if (globalClose) {
      var handleClickOutside = function handleClickOutside(e) {
        if (!toastRef.current.contains(e.target)) {
          handleClose();
        }
      };

      window.addEventListener('mousedown', handleClickOutside);
      return function () {
        window.removeEventListener('mousedown', handleClickOutside);
      };
    }
  }, [globalClose, handleClose]);
  if (!show && !delay) return null;
  return /*#__PURE__*/_jsx("div", {
    className: containerClassName,
    children: /*#__PURE__*/_jsxs("div", {
      className: BASE_CLASS,
      ref: toastRef,
      children: [/*#__PURE__*/_jsx("div", {
        onClick: handleClose,
        className: BASE_CLASS + "-icon",
        children: iconClose
      }), children]
    })
  });
}

AtomToast.displayName = 'AtomToast';
export { POSITIONS as atomToastPositions, AUTO_CLOSE_TIMES as atomToastAutoCloseTimes };
export default AtomToast;
